/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

#ifndef __KZ_FEED_INFO_H__
#define __KZ_FEED_INFO_H__

#include "kz-window.h"

G_BEGIN_DECLS

#define KZ_TYPE_FEED_INFO		(kz_feed_info_get_type ())
#define KZ_FEED_INFO(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_FEED_INFO, KzFeedInfo))
#define KZ_FEED_INFO_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_FEED_INFO, KzFeedInfoClass))
#define KZ_IS_FEED_INFO(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_FEED_INFO))
#define KZ_IS_FEED_INFO_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_FEED_INFO))
#define KZ_FEED_INFO_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_FEED_INFO, KzFeedInfoClass))

typedef struct _KzFeedInfo      KzFeedInfo;
typedef struct _KzFeedInfoClass KzFeedInfoClass;

struct _KzFeedInfo
{
	GtkImageMenuItem parent;

	/* Kazehakase */
	KzWindow *kz;

	/* feed list */
	GSList *feed_list;
};

struct _KzFeedInfoClass
{
	GtkImageMenuItemClass parent_class;
};

GType      kz_feed_info_get_type          (void) G_GNUC_CONST;
GtkWidget *kz_feed_info_new               (KzWindow *kz);
void       kz_feed_info_change_state      (KzFeedInfo *info);

G_END_DECLS

#endif /* __KZ_FEED_INFO_H__ */
